@@ -157,7 +157,7 @@ void AtlanticDesigner::initToken()
 		m_player = new Player(0);
 	else
 		m_player->setLocation(0);
-
+	
 	board->addToken(m_player);
 
 	connect(m_player, SIGNAL(changed(Player *)), board, SLOT(playerChanged(Player *)));
@@ -237,7 +237,7 @@ void AtlanticDesigner::open()
 		return;
 
 	openFile(filename);
-	recentAct->addURL(QString("file:") + filename);
+	recentAct->addURL(KURL::fromPathOrURL( filename ));
 }
 
 void AtlanticDesigner::openRecent(const KURL &url)
@@ -511,7 +511,7 @@ void AtlanticDesigner::openFile(const QString &filename)
 					break;
 				}
 			}
-
+			
 			if (found)
 				continue;
 
@@ -585,7 +585,7 @@ void AtlanticDesigner::saveAs()
 		return;
 	}
 	else
-		recentAct->addURL(QString("file:") + filename);
+		recentAct->addURL(KURL::fromPathOrURL( filename ));
 }
 
 void AtlanticDesigner::save()
@@ -698,7 +698,7 @@ void AtlanticDesigner::save()
 	}
 
 	// now do the cards
-
+	
 	for (QValueList<CardStack>::Iterator it = cards.begin(); it != cards.end(); ++it)
 	{
 		t << endl << endl;
@@ -737,7 +737,7 @@ void AtlanticDesigner::save()
 				{
 					t << "canbeowned=" << 1 << endl;
 				}
-
+				
 				t << key << "=" << value << endl;
 			}
 		}
