@@ -66,15 +66,15 @@ int InitPluginKateFileListLoader::initKate()
 //			application()->activeMainWindow()->viewManager()->openURL(KURL(t.readLine()));
 			application()->documentManager()->openURL(tmpURL=KURL(t.readLine()));
 		}
-		if (!somethingOpened) application()->activeMainWindow()->viewManager()->openURL(KURL());
-		else
+		if (!somethingOpened) application()->documentManager()->openURL(KURL());
+		else if (application()->activeMainWindow())
 		application()->activeMainWindow()->viewManager()->openURL(tmpURL);
 
 		file.close();
 
 		KIO::NetAccess::removeTempFile( tmpFile );
 
-	} else application()->activeMainWindow()->viewManager()->openURL(KURL());
+	} else application()->documentManager()->openURL(KURL());
 
 	Kate::Plugin *pl=application()->pluginManager()->plugin("katefll_plugin");
 	if (pl) 
