@@ -100,7 +100,7 @@ TODO:
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kgenericfactory.h>
-       
+
 K_EXPORT_COMPONENT_FACTORY( katexmltoolsplugin, KGenericFactory<PluginKateXMLTools>( "katexmltools" ) )
 
 class PluginView : public KXMLGUIClient
@@ -172,7 +172,7 @@ void PluginKateXMLTools::backspacePressed()
 
         if (!application()->activeMainWindow())
           return;
-          
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning: no Kate::View" << endl;
@@ -205,7 +205,7 @@ void PluginKateXMLTools::keyEvent(int, int, const QString &/*s*/)
 
         if (!application()->activeMainWindow())
           return;
-        
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning: no Kate::View" << endl;
@@ -420,7 +420,8 @@ void PluginKateXMLTools::getDTD()
 		KMessageBox::information(0, i18n("The current file has been identified "
 			"as a document of type \"%1\". The meta DTD for this document type "
 			"will now be loaded.").arg(doctype),
-			i18n("Loading XML Meta DTD"));
+			i18n("Loading XML Meta DTD"),
+			QString::fromLatin1("DTDAssigned") );
 	}
 
 	// Load the Meta DTD
@@ -449,10 +450,10 @@ void PluginKateXMLTools::slotFinished(KIO::Job *job)
 	} else {
 		PseudoDTD *dtd = new PseudoDTD();
 		dtd->analyzeDTD(m_url_string, m_dtd_string);
-                
+
                 if (!application()->activeMainWindow())
                   return;
-                
+
 		Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 		if( ! kv ) {
 			kdDebug() << "Warning: no Kate::View" << endl;
@@ -557,7 +558,7 @@ void PluginKateXMLTools::filterInsertString(KTextEditor::CompletionEntry *ce, QS
 
         if (!application()->activeMainWindow())
           return;
-        
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning (filterInsertString()): no Kate::View" << endl;
@@ -626,6 +627,19 @@ void PluginKateXMLTools::filterInsertString(KTextEditor::CompletionEntry *ce, QS
 	}
 }
 
+static void correct_pos(Kate::View *kv, int count)
+{
+	if( count > 0 ) {
+		for( int i = 0; i < count; i++ ) {
+			kv->cursorRight();
+		}
+	} else if( count < 0 ) {
+		for( int i = 0; i < -count; i++ ) {
+			kv->cursorLeft();
+		}
+	}
+}
+
 void PluginKateXMLTools::completionAborted()
 {
         if (!application()->activeMainWindow())
@@ -639,13 +653,17 @@ void PluginKateXMLTools::completionAborted()
 	disconnectSlots(kv);
 	kv->cursorPositionReal(&m_last_line, &m_last_col);
 	m_last_col--;
+
+	correct_pos(kv,m_correct_pos);
+	m_correct_pos = 0;
+
 	kdDebug() << "completionAborted() at line:" << m_last_line << ", col:" << m_last_col << endl;
 }
 
 void PluginKateXMLTools::completionDone(KTextEditor::CompletionEntry)
 {
 	kdDebug() << "completionDone()" << endl;
-        
+
         if (!application()->activeMainWindow())
           return;
 
@@ -654,23 +672,16 @@ void PluginKateXMLTools::completionDone(KTextEditor::CompletionEntry)
 		kdDebug() << "Warning (completionDone()): no Kate::View" << endl;
 		return;
 	}
-	disconnectSlots(kv);	
+	disconnectSlots(kv);
 
-	if( m_correct_pos > 0 ) {
-		for( int i = 0; i < m_correct_pos; i++ ) {
-			kv->cursorRight();
-		}
-	} else if( m_correct_pos < 0 ) {
-		for( int i = 0; i < -m_correct_pos; i++ ) {
-			kv->cursorLeft();
-		}
-	}
+	correct_pos(kv,m_correct_pos);
+	m_correct_pos = 0;
 
 	if( m_mode == attributes ) {
 		// immediately show attribute values:
 		QTimer::singleShot(10, this, SLOT(emptyKeyEvent()));
 	}
-	
+
 }
 
 // ========================================================================
@@ -936,7 +947,7 @@ QString InsertElement::showDialog(QStringList &completions)
 	KHistoryCombo *combo = new KHistoryCombo(page, "value");
 	combo->setHistoryItems(completions, true);
 		connect(combo->lineEdit(), SIGNAL(textChanged ( const QString & )),this,SLOT( slotHistoryTextChanged(const QString &)));
-	QString text = i18n("Enter XML tag name and attributes. The \"<\", \">\" and closing tag will be supplied.");
+	QString text = i18n("Enter XML tag name and attributes (\"<\", \">\" and closing tag will be supplied):");
 	QLabel *label = new QLabel(text, page, "insert");
 
 	topLayout->addWidget(label);
