@@ -109,7 +109,7 @@ bool KTxtPlugin::readInfo(KFileMetaInfo& info, uint)
 
     kdDebug(7034) << "Lines: " << totLines << endl;
     kdDebug(7034) << "Words: " << totWords << endl;
-    //kdDebug(7034) << "Characters: " << totChars << endl;
+    kdDebug(7034) << "Characters: " << totChars << endl;
     kdDebug(7034) << "fileFormat: " << fileFormat << endl;
 
     KFileMetaInfoGroup group = appendGroup(info, "General");
