@@ -32,7 +32,7 @@
 // -- KConfDialog definition ---------------------------------------------
 
 KConfDialog::KConfDialog(KTimeMon *t)
-    : KDialogBase( Tabbed, i18n("KTimeMon Configuration" ),
+    : KDialogBase( Tabbed, i18n("Configuration" ),
           Ok|Cancel|Apply, Ok ),
       timemon(t)
 {
