@@ -26,7 +26,7 @@
 
 #ifdef __osf__
 #include <sys/table.h>
-#elif defined(__sun__)
+#elif defined(USE_SOLARIS)
 #include <kstat.h>
 #include <sys/sysinfo.h>
 #include <sys/stat.h>
@@ -42,7 +42,7 @@
 
 // -- global definitions -------------------------------------------------
 
-#if defined(__osf__) || defined(__sun__)
+#if defined(__osf__) || defined(USE_SOLARIS)
 extern "C" int getpagesize();   // argh, have to define prototype!
 #endif
 
@@ -77,7 +77,7 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   timemon(t),
 #ifdef __linux__
   memFD(-1), statFD(-1),
-#elif defined (__sun__)
+#elif defined (USE_SOLARIS)
   kc(0), warned(false),
 #endif
   pageScale(p), swapScale(s), cxScale(c), autoscale(a)
@@ -110,7 +110,7 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
 
   fcntl( statFD,F_SETFD, FD_CLOEXEC );
 
-#elif defined (__sun__)
+#elif defined (USE_SOLARIS)
   if ((kc = kstat_open()) == 0) {
     KMessageBox::error(timemon, i18n("Unable to initialize the 'kstat' library. "
                                      "This library is used for accessing kernel information. "
@@ -122,7 +122,7 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   }
 #endif
 
-#if defined(__sun__) || defined(__osf__)
+#if defined(USE_SOLARIS) || defined(__osf__)
   pagesPerMB = (1024*1024) / getpagesize();
   if (pagesPerMB == 0) pagesPerMB = 1; // paranoia sanity check
 #endif
@@ -137,7 +137,7 @@ KSample::~KSample()
 #ifdef __linux__
   close(memFD);
   close(statFD);
-#elif defined (__sun__)
+#elif defined (USE_SOLARIS)
   if (kc != 0) kstat_close(kc);
 #endif
 }
@@ -151,6 +151,7 @@ void KSample::parseMtab(char *dest)
         KMessageBox::error(timemon, i18n("Unable to open file '%1' to determine where the proc "
                                          "filesystem is mounted. The diagnostics are:\n%2\n"
                                          "Are you really running UNIX?").arg( MTAB_NAME).arg( strerror(errno)));
+        delete mtab;
         exit(1);
     }
 
@@ -245,7 +246,7 @@ void KSample::nonfatal(const QString& msg)
 static inline void
 scan_one(const char* buff, const char *key, unsigned long int* val)
 {
-        char *b = strstr(buff, key);
+        const char *b = strstr(buff, key);
         if (b) {
                 b = strstr(b, " ");
                 if (b)
@@ -361,7 +362,7 @@ void KSample::readSample()
     sample.stotal = swapinfo.size;
     sample.sfree = swapinfo.free;
 
-#elif defined(__sun__)
+#elif defined(USE_SOLARIS)
     kstat_t *ksp;
 
     sample.cpus = 0;
@@ -482,6 +483,8 @@ void KSample::readSample()
         free(stbl);
     }
 
+#else
+#warning This type of system is not supported
 #endif
 
     sample.cputotal = sample.user + sample.nice + sample.kernel + sample.idle;
@@ -501,7 +504,7 @@ inline void KSample::makeMBytes(unsigned long &v)
 {
 #ifdef __linux__
     v /= 1024;                  // can it be simpler ;-)
-#elif defined (__osf__) || defined(__sun__)
+#elif defined (__osf__) || defined(USE_SOLARIS)
     v /= pagesPerMB;
 #endif
 }
