@@ -16,7 +16,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: domtreeview.h,v 1.12 2002/08/25 09:51:01 mlaurent Exp $ */
+/* $Id: domtreeview.h,v 1.14 2003/11/03 17:18:00 nhasan Exp $ */
 
 #ifndef DOMTREEVIEW_H
 #define DOMTREEVIEW_H
@@ -25,17 +25,17 @@
 #include <dom/dom_core.h>
 #include <qtextstream.h>
 
-#include <kdebug.h>
 #include <kdialog.h>
-#include <klistview.h>
 #include <keditcl.h>
 
 #include "domlistviewitem.h"
 
 class QVBoxLayout;
 class QHBoxLayout;
-class QPushButton;
 class QCheckBox;
+class QTextStream;
+class KPushButton;
+class KListView;
 
 class DOMTreeView : public KDialog
 {
@@ -99,12 +99,12 @@ class DOMTreeView : public KDialog
 	QCheckBox* m_showAttributesCheckBox;
 	QCheckBox* m_highlightHTMLCheckBox;
 
-	QPushButton* m_decreaseButton;
-	QPushButton* m_increaseButton;
-	QPushButton* m_findButton;
-	QPushButton* m_saveButton;
-	QPushButton* m_refreshButton;
-	QPushButton* m_closeButton;
+	KPushButton* m_decreaseButton;
+	KPushButton* m_increaseButton;
+	KPushButton* m_findButton;
+	KPushButton* m_saveButton;
+	KPushButton* m_refreshButton;
+	KPushButton* m_closeButton;
 
 	QVBoxLayout* m_vLayout1;
 	QVBoxLayout* m_vLayout2;
