@@ -346,7 +346,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
 
   QRect r = _rect;
 
-  if (0) kdDebug() << "DrawField: Rect " << r.x() << "/" << r.y()
+  if (0) kdDebug(90100) << "DrawField: Rect " << r.x() << "/" << r.y()
 		   << " - " << r.width() << "x" << r.height() << endl;
 
   int h = _fontHeight;
@@ -506,7 +506,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
   // width of text and pixmap to be drawn
   int w = pixW + _fm->width(name);
 
-  if (0) kdDebug() << "  For '" << name << "': Unused " << unused
+  if (0) kdDebug(90100) << "  For '" << name << "': Unused " << unused
 		   << ", StrW " << w << ", Width " << width << endl;
 
   // if we have limited space at 1st line:
@@ -626,7 +626,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
         len--;
         w = pixW + _fm->width(name, len) + dotW;
       }
-      // stop drawing: we can't draw 2 chars + "..."
+      // stop drawing: we cannot draw 2 chars + "..."
       if (w>width) break;
 
       name = name.left(len) + "...";
@@ -650,7 +650,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
     }
 
 
-    if (0) kdDebug() << "  Drawing '" << name << "' at " 
+    if (0) kdDebug(90100) << "  Drawing '" << name << "' at " 
 		     << x+pixW << "/" << y << endl;
 
     p->drawText( x+pixW, y,
@@ -766,7 +766,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value)
   if (_parent) {
     // take sorting from parent
     _sortTextNo = _parent->sorting(&_sortAscending);
-    addItem(_parent);
+    _parent->addItem(this);
   }
   else {
     _sortAscending = false;
@@ -796,7 +796,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
   _unused_self = 0;
   _freeRects = 0;
 
-  if (_parent) addItem(_parent);
+  if (_parent) _parent->addItem(this);
 }
 
 TreeMapItem::~TreeMapItem()
@@ -1032,7 +1032,7 @@ void TreeMapItem::addFreeRect(const QRect& r)
 	_freeRects->setAutoDelete(true);
     }
 
-    if (0) kdDebug() << "addFree(" << path(0).join("/") << ", "
+    if (0) kdDebug(90100) << "addFree(" << path(0).join("/") << ", "
 		     << r.x() << "/" << r.y() << "-"
 		     << r.width() << "x" << r.height() << ")" << endl;
 
@@ -1064,7 +1064,7 @@ void TreeMapItem::addFreeRect(const QRect& r)
 	return;
     }
 
-    if (0) kdDebug() << "  united with last to (" 
+    if (0) kdDebug(90100) << "  united with last to (" 
 		     << last->x() << "/" << last->y() << "-"
 		     << last->width() << "x" << last->height() << ")" << endl;
 }
@@ -1479,7 +1479,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
   TreeMapItem* i;
 
   if (!rect().contains(x, y)) return 0;
-  if (DEBUG_DRAWING) kdDebug() << "item(" << x << "," << y << "):" << endl;
+  if (DEBUG_DRAWING) kdDebug(90100) << "item(" << x << "," << y << "):" << endl;
 
   while (1) {
     TreeMapItemList* list = p->children();
@@ -1490,14 +1490,14 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
       for (i=list->first();i;i=list->next(),idx++) {
 
         if (DEBUG_DRAWING)
-	    kdDebug() << "  Checking " << i->path(0).join("/") << " ("
+	    kdDebug(90100) << "  Checking " << i->path(0).join("/") << " ("
 		      << i->itemRect().x() << "/" << i->itemRect().y()
 		      << "-" << i->itemRect().width() 
 		      << "x" << i->itemRect().height() << ")" << endl;
 
         if (i->itemRect().contains(x, y)) {
 
-	    if (DEBUG_DRAWING) kdDebug() << "  .. Got. Index " << idx << endl;
+	    if (DEBUG_DRAWING) kdDebug(90100) << "  .. Got. Index " << idx << endl;
 
 	    p->setIndex(idx);
 	    break;
@@ -1511,7 +1511,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
         last = p;
 
         if (DEBUG_DRAWING)
-	    kdDebug() << "item(" << x << "," << y << "): Got " 
+	    kdDebug(90100) << "item(" << x << "," << y << "): Got " 
 		      << p->path(0).join("/") << " (Size " 
 		      << p->itemRect().width() << "x" << p->itemRect().height()
 		      << ", Val " << p->value() << ")" << endl;
@@ -1571,7 +1571,7 @@ void TreeMapWidget::setSelected(TreeMapItem* item, bool selected)
     emit selectionChanged();
     redraw(changed);
     
-    if (0) kdDebug() << (selected ? "S":"Des") << "elected Item "
+    if (0) kdDebug(90100) << (selected ? "S":"Des") << "elected Item "
 		     << (item ? item->path(0).join("") : QString("(null)"))
 		     << " (depth " << (item ? item->depth() : -1) 
 		     << ")" << endl;
@@ -1685,7 +1685,7 @@ void TreeMapWidget::setCurrent(TreeMapItem* i, bool kbd)
 	// remove mark
 	_markNo = 0;
 
-	if (1) kdDebug() << "setCurrent(" << i->path(0).join("/")
+	if (1) kdDebug(90100) << "setCurrent(" << i->path(0).join("/")
 			 << ") - mark removed" << endl;
 
 	// always complete redraw needed to remove mark
@@ -1700,7 +1700,7 @@ void TreeMapWidget::setCurrent(TreeMapItem* i, bool kbd)
 	if (i) i->redraw();
     }
 
-    //kdDebug() << "Current Item " << (i ? i->path().ascii() : "(null)") << endl;
+    //kdDebug(90100) << "Current Item " << (i ? i->path().ascii() : "(null)") << endl;
 
     emit currentChanged(i, kbd);
 }
@@ -1764,7 +1764,7 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
 
 void TreeMapWidget::contextMenuEvent( QContextMenuEvent* e )
 {
-  //kdDebug() << "TreeMapWidget::contextMenuEvent" << endl;
+  //kdDebug(90100) << "TreeMapWidget::contextMenuEvent" << endl;
 
   if ( receivers( SIGNAL(contextMenuRequested(TreeMapItem*, const QPoint &)) ) )
     e->accept();
@@ -1783,7 +1783,7 @@ void TreeMapWidget::contextMenuEvent( QContextMenuEvent* e )
 
 void TreeMapWidget::mousePressEvent( QMouseEvent* e )
 {
-  //kdDebug() << "TreeMapWidget::mousePressEvent" << endl;
+  //kdDebug(90100) << "TreeMapWidget::mousePressEvent" << endl;
 
   _oldCurrent = _current;
 
@@ -1823,12 +1823,18 @@ void TreeMapWidget::mousePressEvent( QMouseEvent* e )
     break;
   }
 
+  // item under mouse always selected on right button press
+  if (e->button() == RightButton) {
+    TreeMapItem* changed2 = setTmpSelected(item, true);
+    if (changed2) changed = changed2->commonParent(changed);
+  }
+
   setCurrent(_pressed);
 
   if (changed)
     redraw(changed);
 
-  if (e->button() == RightButton) {
+  if (e->button() == RightButton) {    
 
     // emit selection change
     if (! (_tmpSelection == _selection)) {
@@ -1845,7 +1851,7 @@ void TreeMapWidget::mousePressEvent( QMouseEvent* e )
 
 void TreeMapWidget::mouseMoveEvent( QMouseEvent* e )
 {
-  //kdDebug() << "TreeMapWidget::mouseMoveEvent" << endl;
+  //kdDebug(90100) << "TreeMapWidget::mouseMoveEvent" << endl;
 
   if (!_pressed) return;
   TreeMapItem* over = item(e->x(), e->y());
@@ -1888,7 +1894,7 @@ void TreeMapWidget::mouseMoveEvent( QMouseEvent* e )
 
 void TreeMapWidget::mouseReleaseEvent( QMouseEvent* )
 {
-  //kdDebug() << "TreeMapWidget::mouseReleaseEvent" << endl;
+  //kdDebug(90100) << "TreeMapWidget::mouseReleaseEvent" << endl;
 
   if (!_pressed) return;
 
@@ -2113,7 +2119,7 @@ void TreeMapWidget::drawTreeMap()
   if (_needsRefresh) {
 
     if (DEBUG_DRAWING)
-      kdDebug() << "Redrawing " << _needsRefresh->path(0).join("/") << endl;
+      kdDebug(90100) << "Redrawing " << _needsRefresh->path(0).join("/") << endl;
     
     if (_needsRefresh == _base) {
       // redraw whole widget
@@ -2223,7 +2229,7 @@ void TreeMapWidget::drawItems(QPainter* p,
                               TreeMapItem* item)
 {
     if (DEBUG_DRAWING)
-	kdDebug() << "+drawItems(" << item->path(0).join("/") << ", "
+	kdDebug(90100) << "+drawItems(" << item->path(0).join("/") << ", "
 		  << item->itemRect().x() << "/" << item->itemRect().y()
 		  << "-" << item->itemRect().width() << "x"
 		  << item->itemRect().height() << "), Val " << item->value()
@@ -2294,7 +2300,7 @@ void TreeMapWidget::drawItems(QPainter* p,
     r = d.remainingRect(item);
 
     if (DEBUG_DRAWING)
-	kdDebug() << "-drawItems(" << item->path(0).join("/") << ")" << endl;
+	kdDebug(90100) << "-drawItems(" << item->path(0).join("/") << ")" << endl;
     return;
   }
 
@@ -2308,7 +2314,7 @@ void TreeMapWidget::drawItems(QPainter* p,
   for (i=list->first();i;i=list->next()) {
     child_sum += i->value();
     if (DEBUG_DRAWING)
-      kdDebug() << "  child: " << i->text(0) << ", value " 
+      kdDebug(90100) << "  child: " << i->text(0) << ", value " 
 		<< i->value() << endl;
   }
 
@@ -2347,7 +2353,7 @@ void TreeMapWidget::drawItems(QPainter* p,
     self = user_sum - child_sum;
 
     if (user_sum < child_sum) {
-      //kdDebug() << "TreeMWidget " <<
+      //kdDebug(90100) << "TreeMWidget " <<
       //       item->path() << ": User sum " << user_sum << " < Child Items sum " << child_sum << endl;
 
       // invalid user supplied sum: ignore and use calculate sum
@@ -2394,7 +2400,7 @@ void TreeMapWidget::drawItems(QPainter* p,
     // set selfRect (not occupied by children) for tooltip
     item->addFreeRect(sr);
 
-    if (0) kdDebug() << "Item " << item->path(0).join("/") << ": SelfR "
+    if (0) kdDebug(90100) << "Item " << item->path(0).join("/") << ": SelfR "
 		     << sr.x() << "/" << sr.y() << "-" << sr.width()
 		     << "/" << sr.height() << ", self " << self << "/"
 		     << user_sum << endl;
@@ -2526,7 +2532,7 @@ void TreeMapWidget::drawItems(QPainter* p,
     drawItemArray(p, item, r, user_sum, it, list->count(), goBack);
 
   if (DEBUG_DRAWING)
-      kdDebug() << "-drawItems(" << item->path(0).join("/") << ")" << endl;
+      kdDebug(90100) << "-drawItems(" << item->path(0).join("/") << ")" << endl;
 }
 
 // fills area with a pattern if to small to draw children
@@ -2543,7 +2549,7 @@ void TreeMapWidget::drawFill(TreeMapItem* i, QPainter* p, QRect& r,
                              TreeMapItemListIterator it, int len, bool goBack)
 {
   if (DEBUG_DRAWING)
-      kdDebug() << "  +drawFill(" << r.x() << "/" << r.y()
+      kdDebug(90100) << "  +drawFill(" << r.x() << "/" << r.y()
 		<< "-" << r.width() << "x" << r.height()
 		<< ", len " << len << ")" << endl;
 
@@ -2556,14 +2562,14 @@ void TreeMapWidget::drawFill(TreeMapItem* i, QPainter* p, QRect& r,
   while (len>0 && it.current()) {
 
       if (DEBUG_DRAWING)
-	  kdDebug() << "   Reset Rect " << (*it)->path(0).join("/") << endl;
+	  kdDebug(90100) << "   Reset Rect " << (*it)->path(0).join("/") << endl;
 
       (*it)->clearItemRect();
       if (goBack) --it; else ++it;
       len--;
   }
   if (DEBUG_DRAWING)
-      kdDebug() << "  -drawFill(" << r.x() << "/" << r.y()
+      kdDebug(90100) << "  -drawFill(" << r.x() << "/" << r.y()
 		<< "-" << r.width() << "x" << r.height()
 		<< ", len " << len << ")" << endl;
 }
@@ -2589,7 +2595,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
   }
 
   if (DEBUG_DRAWING)
-      kdDebug() << " +drawItemArray(" << item->path(0).join("/") 
+      kdDebug(90100) << " +drawItemArray(" << item->path(0).join("/") 
 		<< ", " << r.x() << "/" << r.y() << "-" << r.width()
 		<< "x" << r.height() << ")" << endl;
 
@@ -2635,7 +2641,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
     }
 
     if (DEBUG_DRAWING)
-	kdDebug() << " -drawItemArray(" << item->path(0).join("/")
+	kdDebug(90100) << " -drawItemArray(" << item->path(0).join("/")
 		  << ")" << endl;
 
     return drawOn;
@@ -2649,7 +2655,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
     if (user_sum <= 0) {
 
       if (DEBUG_DRAWING)
-	  kdDebug() << "drawItemArray: Reset " << i->path(0).join("/") << endl;
+	  kdDebug(90100) << "drawItemArray: Reset " << i->path(0).join("/") << endl;
 
       i->clearItemRect();
       if (goBack) --it; else ++it;
@@ -2665,7 +2671,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
 
       drawFill(item, p, r, it, len, goBack);
       if (DEBUG_DRAWING)
-	  kdDebug() << " -drawItemArray(" << item->path(0).join("/")
+	  kdDebug(90100) << " -drawItemArray(" << item->path(0).join("/")
 		    << "): Stop" << endl;
       return false;
     }
@@ -2681,7 +2687,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
     if ((item->sorting(0) != -1) && (nextPos < _visibleWidth)) {
       drawFill(item, p, r, it, len, goBack);
       if (DEBUG_DRAWING)
-	  kdDebug() << " -drawItemArray(" << item->path(0).join("/")
+	  kdDebug(90100) << " -drawItemArray(" << item->path(0).join("/")
 		    << "): Stop" << endl;
       return false;
     }
@@ -2736,7 +2742,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
   }
 
   if (DEBUG_DRAWING)
-      kdDebug() << " -drawItemArray(" << item->path(0).join("/")
+      kdDebug(90100) << " -drawItemArray(" << item->path(0).join("/")
 		<< "): Continue" << endl;
 
   return true;
