@@ -631,7 +631,7 @@ MAKERNOTE_CANON_TAG_0x004={
 def s2n_motorola(str):
     x=0
     for c in str:
-        x=(x << 8) | ord(c)
+        x=(long(x) << 8) | ord(c)
     return x
 
 # extract multibyte integer in Intel format (big endian)
@@ -707,7 +707,7 @@ class EXIF_header:
             val=s2n_motorola(slice)
         # Sign extension ?
         if signed:
-            msb=1 << (8*length-1)
+            msb=1L << (8*length-1)
             if val & msb:
                 val=val-(msb << 1)
         return val
