@@ -23,6 +23,7 @@
 
 #include <kaction.h>
 #include <kiconloader.h>
+#include <kio/global.h>
 #include <klocale.h>
 #include <kurl.h>
 
@@ -57,7 +58,8 @@ KDirMenu::~KDirMenu( ) {
 }
 void KDirMenu::insert( KDirMenu *submenu, const QString &_path ) {
     static const QIconSet folder = SmallIconSet("folder");
-    insertItem ( folder , _path,  submenu  );
+    QString escapedPath = _path;
+    insertItem( folder, escapedPath.replace( "&", "&&" ), submenu );
     children.append( submenu );
     connect(submenu, SIGNAL(fileChosen(const QString &)),
             this, SLOT(slotFileSelected(const QString &)));
@@ -77,31 +79,35 @@ void KDirMenu::slotAboutToShow( ) {
         action->plug( this );
     else
 	setItemEnabled( insertItem( name ), false );
-    insertSeparator( );
 
     // all dirs writeable and readable
     QDir dir(path, QString::null,
              QDir::Name | QDir::DirsFirst | QDir::IgnoreCase,
              QDir::Dirs | QDir::Readable | QDir::Executable);
 
-    QFileInfoList dirList = QFileInfoList(*(dir.entryInfoList()));
+    const QFileInfoList* dirList = dir.entryInfoList();
+    if ( !dirList || dirList->isEmpty() ) {
+        action->setEnabled( false );
+	return;
+    }
 
-    if (dirList.count() == 2) {
+    insertSeparator( );
+
+    if (dirList->count() == 2) {
         insertItem(i18n("No Sub-Folders"), 0);
         setItemEnabled(0, false);
         return;
     }
 
-    QFileInfo* fi;
-    QString fileName;
     static const QString& dot = KGlobal::staticQString( "." );
     static const QString& dotdot = KGlobal::staticQString( ".." );
-    for (fi = dirList.first(); fi; fi = dirList.next()) {
-        fileName = fi->fileName();
+
+    for ( QFileInfoListIterator it( *dirList ); *it; ++it ) {
+        QString fileName = (*it)->fileName();
         if ( fileName == dot || fileName == dotdot )
             continue;
-        insert(new KDirMenu(this, src, fi->absFilePath(), name),
-               fileName);
+        insert(new KDirMenu(this, src, (*it)->absFilePath(), name),
+			KIO::decodeFileName( fileName ));
     }
 }
 void KDirMenu::slotAboutToHide( ) {
@@ -112,7 +118,7 @@ void KDirMenu::initIconMap()
     if(_icons) return;
 
 /* not used yet
-//    kdDebug() << "PanelBrowserMenu::initIconMap" << endl;
+//    kdDebug(90160) << "PanelBrowserMenu::initIconMap" << endl;
 
     _icons = new QMap<QString, QPixmap>;
 
