@@ -18,6 +18,7 @@
 */
 
 #include <kiconloader.h>
+#include <kimproxy.h>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
@@ -32,10 +33,11 @@
 
 #include "kmetamenu.h"
 #include "kdirmenu.h"
+#include "kimcontactmenu.h"
 #include "kmetamenu.moc"
 
 KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
-        const QString &text, const QString &key)
+        const QString &text, const QString &key, KIMProxy *imProxy )
 : QPopupMenu( parent),
   m_root( 0 ), m_home( 0 ), m_etc( 0 ), m_current( 0 ), m_browse( 0 ) {
      int recent_no;
@@ -85,6 +87,16 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
      connect(m_home, SIGNAL(fileChosen(const QString &)),
              SLOT(slotFileChosen(const QString &) ) );
 
+    if ( imProxy )
+    {
+        m_contacts = new KIMContactMenu( parent, imProxy );
+        int item = insertItem( SmallIconSet( "personal" ), i18n( "C&ontact" ), m_contacts );
+        connect ( m_contacts, SIGNAL( contactChosen( const QString &) ), SIGNAL( contactChosen( const QString & ) ) );
+        if ( !imProxy->initialize() && imProxy->imAppsAvailable() )
+          setItemEnabled( item, false );
+    }
+     
+     
      m_browse = new KAction(i18n("&Browse..."), 0, this, SLOT(slotBrowse()), this );
      m_browse->plug(this);
      // read the last chosen dirs
@@ -96,15 +108,24 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
      if ( list.count() > 0 )
          insertSeparator();
      int i=1;
-     for( QStringList::Iterator it =list.begin(); it != list.end(); ++it) {
+     QStringList::Iterator it = list.begin();
+     while( it != list.end() ) {
          if( i == (recent_no + 1) )
 	     break;
-         KAction *action = new KAction(*it, 0, this, SLOT(slotFastPath() ), this );
+         QDir dir( *it );
+         if ( !dir.exists() ) {
+             it = list.remove( it );
+             continue;
+         }
+         QString escapedDir = *it;
+         KAction *action = new KAction(escapedDir.replace("&", "&&"), 0, this, SLOT(slotFastPath()), this);
          action->plug(this );
          actions.append( action );
+         ++it;
          i++;
      }
 }
+
 KMetaMenu::KMetaMenu( ){
 
 }
@@ -120,6 +141,7 @@ void KMetaMenu::slotFileChosen(const QString &path ){
      writeConfig(path );
      emit fileChosen(path );
 }
+
 void KMetaMenu::slotFastPath( ) {
      KAction *action;
      action = (KAction*) sender();
@@ -129,6 +151,9 @@ void KMetaMenu::slotFastPath( ) {
 void KMetaMenu::writeConfig( const QString &path){
      list.remove(path );
      list.prepend(path );
+     int c = conf->readNumEntry( "ShowRecent", 5 );
+     while ( list.count() > c && !list.isEmpty() )
+        list.remove(list.last()); 
      conf->setGroup( group );
      conf->writePathEntry("Paths", list);
      conf->sync( );
