@@ -25,12 +25,15 @@
 #include <kshortcut.h>
 #include <kdebug.h>
 #include <kaction.h>
+#include <kaboutdata.h>
 
 #include <qdir.h>
 
 SmbmounterPlugin::SmbmounterPlugin(QObject* parent, const char* name, const QStringList& )
 :KParts::Plugin(parent, name)
 {
+   setInstance(KGenericFactory<SmbmounterPlugin>::instance());
+
    //I don't think we have to check for "shell access" here, if a "kiosk" admin
    //doesn't want to provide samba network access, he simply can delete
    //the smb.protocol file, Alex
@@ -97,9 +100,6 @@ void SmbmounterPlugin::smbmount()
    tmp+=m_share;
    s<<tmp;
    s<<m_path;
-   tmp="";
-   s<<tmp;   //no user
-   s<<tmp;   //no password
 
    KIO::SimpleJob *mountJob=KIO::special(dummyUrl, data, false);
    m_smbumountAction->setEnabled(false);
@@ -133,7 +133,7 @@ void SmbmounterPlugin::smbumount()
 void SmbmounterPlugin::mountResult(KIO::Job *job)
 {
    if (job && job->error())
-      KMessageBox::information(0,i18n("<qt>Mounting of share <b>%1</b> from host <b>%2</b> failed.</qt>").arg(m_share).arg(m_host));
+      job->showErrorDialog(0);
    else
       KMessageBox::information(0,i18n("<qt>The share <b>%1</b> from host <b>%2</b> has been mounted under <b>%3</b>.</qt>").arg(m_share).arg(m_host).arg(m_path));
    updateActions();
@@ -142,7 +142,7 @@ void SmbmounterPlugin::mountResult(KIO::Job *job)
 void SmbmounterPlugin::umountResult(KIO::Job *job)
 {
    if (job && job->error())
-      KMessageBox::information(0,i18n("<qt>Umounting of share <b>%1</b> from host <b>%2</b> failed.</qt>").arg(m_share).arg(m_host));
+      job->showErrorDialog(0);
    else
       KMessageBox::information(0,i18n("<qt>The share <b>%1</b> from host <b>%2</b> has been umounted from <b>%3</b></qt>.").arg(m_share).arg(m_host).arg(m_path));
    updateActions();
@@ -202,7 +202,8 @@ bool SmbmounterPlugin::isMounted(const QString& path)
    return (mtabContents.contains(path));
 }
 
-K_EXPORT_COMPONENT_FACTORY( konq_smbmounterplugin, KGenericFactory<SmbmounterPlugin> )
+static const KAboutData aboutdata("konq_smbmounterplugin", I18N_NOOP("Smbmount") , "1.0" );
+K_EXPORT_COMPONENT_FACTORY( konq_smbmounterplugin, KGenericFactory<SmbmounterPlugin>(&aboutdata) )
 
 #include "smbmounterplugin.moc"
 
