@@ -24,7 +24,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_validators.cpp,v 1.21 2003/10/04 14:56:12 adawit Exp $ */
+/* $Id: plugin_validators.cpp,v 1.25 2004/06/24 19:44:18 binner Exp $ */
 
 #include <kinstance.h>
 #include <kmessagebox.h>
@@ -33,19 +33,23 @@
 #include <khtml_part.h>
 #include <kgenericfactory.h>
 #include <kdebug.h>
+#include <kaboutdata.h>
 
 #include "plugin_validators.h"
 #include "validatorsdialog.h"
 
 
 typedef KGenericFactory<PluginValidators> PluginValidatorsFactory;
+static const KAboutData aboutdata("validatorsplugin", I18N_NOOP("Validate Web Page") , "1.0" );
 K_EXPORT_COMPONENT_FACTORY( libvalidatorsplugin,
-	                    PluginValidatorsFactory( "validatorsplugin" ) )
+	                    PluginValidatorsFactory( &aboutdata ) )
 
 PluginValidators::PluginValidators( QObject* parent, const char* name,
                                     const QStringList & )
   : Plugin( parent, name ), m_configDialog(0), m_part(0)
 {
+  setInstance(PluginValidatorsFactory::instance());
+
   m_menu = new KActionMenu ( i18n( "&Validate Web Page" ), "validators",
 			     actionCollection(), "validateWebpage" );
   m_menu->setDelayed( false );
@@ -61,7 +65,7 @@ PluginValidators::PluginValidators( QObject* parent, const char* name,
 			       actionCollection(), "validateCSS") );
 
   m_menu->insert( new KAction( i18n( "Validate &Links" ),
-			       "linkvalidator", 0,
+			       0,
 			       this, SLOT(slotValidateLinks()),
 			       actionCollection(), "validateLinks") );
 
@@ -163,9 +167,9 @@ void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
   if (partUrl.isLocalFile())
     {
       if ( validatorUrl.isEmpty() ) {
-        QString title = i18n( "Upload not possible" );
+        QString title = i18n( "Upload Not Possible" );
         QString text = i18n( "Validating links is not possible for local "
-                             "files" );
+                             "files." );
         KMessageBox::sorry( 0, text, title );
         return;
       }
@@ -190,7 +194,7 @@ void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
       p += q;
       validatorUrl.setQuery( p );
     }
-  kdDebug() << "final URL: " << validatorUrl.url() << endl;
+  kdDebug(90120) << "final URL: " << validatorUrl.url() << endl;
 
   emit m_part->browserExtension()->openURLRequest( validatorUrl );
 }
