@@ -22,6 +22,7 @@
 #include <qgroupbox.h>
 #include <qlayout.h>
 #include <qcombobox.h>
+#include <kconfig.h>
 
 #include <klocale.h>
 
@@ -70,6 +71,18 @@ ValidatorsDialog::ValidatorsDialog(QWidget *parent,  const char *name )
   m_CSSValidatorUploadCB->setDuplicatesEnabled(false);
   vlay2->addWidget( m_CSSValidatorUploadCB );
 
+  ///
+
+  QGroupBox *group3= new QGroupBox( i18n("Link Validator"), page );
+  QVBoxLayout *vlay3 = new QVBoxLayout( group3, spacingHint() );
+  vlay3->addSpacing( fontMetrics().lineSpacing());
+
+  vlay3->addWidget(new QLabel( i18n("URL:"), group3));
+
+  m_linkValidatorCB = new QComboBox(true, group3);
+  m_linkValidatorCB->setDuplicatesEnabled(false);
+  vlay3->addWidget( m_linkValidatorCB );
+
   this->load();
 }
 
@@ -95,6 +108,12 @@ void ValidatorsDialog::load()
   }
   m_CSSValidatorCB->setCurrentItem(m_config->readNumEntry("CSSValidatorUrlIndex",0));
 
+  m_linkValidatorCB->insertStringList(m_config->readListEntry("LinkValidatorUrl"));
+  if (m_linkValidatorCB->count()==0) {
+    m_linkValidatorCB->insertItem("http://validator.w3.org/checklink/");
+  }
+  m_linkValidatorCB->setCurrentItem(m_config->readNumEntry("LinkValidatorUrlIndex",0));
+
   m_WWWValidatorUploadCB->insertStringList(m_config->readListEntry("WWWValidatorUploadUrl"));
   if (m_WWWValidatorUploadCB->count()==0) {
     m_WWWValidatorUploadCB->insertItem("http://validator.w3.org/file-upload.html");
@@ -121,6 +140,11 @@ void ValidatorsDialog::save()
   }
   m_config->writeEntry( "CSSValidatorUrl", strList );
   strList.clear();
+  for (int i = 0; i < m_linkValidatorCB->count(); i++) {
+    strList.append(m_linkValidatorCB->text(i));
+  }
+  m_config->writeEntry( "LinkValidatorUrl", strList );
+  strList.clear();
   for (int i = 0; i < m_WWWValidatorUploadCB->count(); i++) {
     strList.append(m_WWWValidatorUploadCB->text(i));
   }
@@ -133,6 +157,7 @@ void ValidatorsDialog::save()
 
   m_config->writeEntry( "WWWValidatorUrlIndex", m_WWWValidatorCB->currentItem() );
   m_config->writeEntry( "CSSValidatorUrlIndex", m_CSSValidatorCB->currentItem() );
+  m_config->writeEntry( "LinkValidatorUrlIndex", m_linkValidatorCB->currentItem() );
   m_config->writeEntry( "WWWValidatorUploadUrlIndex", m_WWWValidatorUploadCB->currentItem() );
   m_config->writeEntry( "CSSValidatorUploadUrlIndex", m_CSSValidatorUploadCB->currentItem() );
   m_config->sync();
