@@ -17,19 +17,13 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_webarchiver.h,v 1.4 2001/10/29 16:34:03 hausmann Exp $ */
+/* $Id: plugin_webarchiver.h,v 1.7 2003/08/28 22:23:34 antlarr Exp $ */
 
 #ifndef plugin_webarchiver_h
 #define plugin_webarchiver_h
 
-#include <dom/dom_core.h>
-#include <qtextstream.h>
-#include <qdict.h>
 #include <kparts/plugin.h>
 #include <klibloader.h>
-#include <ktar.h>
-
-class KURL;
 
 class PluginWebArchiver : public KParts::Plugin
 {
@@ -43,21 +37,6 @@ class PluginWebArchiver : public KParts::Plugin
  public slots:
    void slotSaveToArchive();
 
- private:
-   void saveFile( const QString& fileName, const KHTMLPart *part);
-   void saveToArchive(const KHTMLPart *part, QTextStream* _textStream);
-   void saveArchiveRecursive(const DOM::Node &node, const KURL& baseURL,
-			     QTextStream* _textStream, int ident);
-   QString handleLink(const KURL& _url, const QString & _link);
-   KURL getAbsoluteURL(const KURL& _url, const QString& _link);
-   QString getUniqueFileName(const QString& fileName);
-   QString stringToHTML(const QString& string);
-   QString analyzeInternalCSS(const KURL& _url, const QString& string);
-   
-   QDict<QString> * m_downloadedURLDict; 
-   QDict<QString> * m_linkDict;
-   KTarGz* m_tarBall;
-   bool m_bPreserveWS;
 };
 
 #endif
