@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: webarchivecreator.cpp,v 1.3.2.1 2003/05/19 14:47:11 mueller Exp $
+// $Id: webarchivecreator.cpp,v 1.5 2004/04/19 19:02:10 mueller Exp $
 
 #include <time.h>
 
@@ -58,7 +58,7 @@ bool WebArchiveCreator::create(const QString &path, int width, int height, QImag
 		m_html->setJavaEnabled(false);
 		m_html->setPluginsEnabled(false);
 	}
-	m_html->openURL("tar:" + path + "/index.html");
+	m_html->openURL(KURL( "tar:" + path + "/index.html" ));
 	m_completed = false;
 	startTimer(5000);
 	while (!m_completed)
