@@ -65,7 +65,7 @@ LyricsCModule::LyricsCModule(QObject *_parent) : CModule(i18n("Lyrics"), i18n("C
   boxlayout->addWidget( boxButtons );
 
   // Edit box
-  QGroupBox *propBox = new QVGroupBox( i18n("Search Provider's Properties" ), this );
+  QGroupBox *propBox = new QVGroupBox( i18n("Search Provider Properties" ), this );
   QGrid *editGrid = new QGrid(2, propBox );
   editGrid->setSpacing(  propBox->insideSpacing() );
   new QLabel( i18n( "Name:" ), editGrid );
@@ -93,7 +93,7 @@ LyricsCModule::LyricsCModule(QObject *_parent) : CModule(i18n("Lyrics"), i18n("C
 }
 
 void LyricsCModule::newSearch(QString name, QString query) {
-  kdDebug() << "New search" << endl;
+  kdDebug(90020) << "New search" << endl;
   SearchProvider s = { name, query };
   mProviders.push_back( s );
   providersBox->insertItem( name );
@@ -105,7 +105,7 @@ void LyricsCModule::newSearch(QString name, QString query) {
 }
 
 void LyricsCModule::selected( QListBoxItem *i ) {
-  kdDebug() << "selected" << endl;
+  kdDebug(90020) << "selected" << endl;
   int index = providersBox->index( i );
   if ( index < 0 )
     return;
@@ -160,7 +160,7 @@ void LyricsCModule::moveDownSearch() {
 }
 
 void LyricsCModule::nameChanged( const QString &name ) {
-  kdDebug() << "name changed" << endl;
+  kdDebug(90020) << "name changed" << endl;
   if ( providersBox->currentItem() < 0 )
     return;
   mProviders[ providersBox->currentItem() ].name = name;
@@ -169,7 +169,7 @@ void LyricsCModule::nameChanged( const QString &name ) {
 }
 
 void LyricsCModule::queryChanged( const QString &query ) {
-  kdDebug() << "query changed" << endl;
+  kdDebug(90020) << "query changed" << endl;
   if ( providersBox->currentItem() < 0 )
     return;
   mProviders[ providersBox->currentItem() ].url = query;
@@ -182,7 +182,7 @@ void LyricsCModule::save() {
   QStringList queryList, nameList;
   QValueVector<SearchProvider>::iterator it;
   for ( it = mProviders.begin(); it != mProviders.end(); ++it ) {
-    kdDebug() << "query:" << ( *it ).url << endl;
+    kdDebug(90020) << "query:" << ( *it ).url << endl;
     queryList += ( *it ).url;
     nameList += ( *it ).name;
   }
@@ -199,7 +199,7 @@ void LyricsCModule::reopen() {
   KConfig *conf = KGlobal::config();
   mProviders.clear();
   providersBox->clear();
-  kdDebug() << "config read" << endl;
+  kdDebug(90020) << "config read" << endl;
   conf->setGroup( "Lyrics" );
   queryList = conf->readListEntry( "queryList" );
   nameList = conf->readListEntry( "nameList" );
@@ -209,7 +209,7 @@ void LyricsCModule::reopen() {
   }
   QStringList::Iterator queryIt, nameIt;
   for ( queryIt = queryList.begin(), nameIt = nameList.begin(); queryIt != queryList.end() && nameIt != nameList.end(); ++queryIt, ++nameIt ) {
-    kdDebug() << "Read:" << *queryIt << " and " << *nameIt << endl;
+    kdDebug(90020) << "Read:" << *queryIt << " and " << *nameIt << endl;
     newSearch( *nameIt, *queryIt );
   }
 }
