@@ -22,7 +22,7 @@ Bitmap *BitmapPool::get(bool clear)
 {
 	mMutex.lock();
 	BitmapPool::PoolItem *p=0;
-	for (QListIterator<BitmapPool::PoolItem> i(mBitmaps); i.current(); ++i)
+	for (QPtrListIterator<BitmapPool::PoolItem> i(mBitmaps); i.current(); ++i)
 	{
 		if (!(*i)->used)
 			p=*i;
@@ -44,7 +44,7 @@ Bitmap *BitmapPool::get(bool clear)
 void BitmapPool::release(Bitmap *bitmap)
 {
 	mMutex.lock();
-	for (QListIterator<BitmapPool::PoolItem> i(mBitmaps); i.current(); ++i)
+	for (QPtrListIterator<BitmapPool::PoolItem> i(mBitmaps); i.current(); ++i)
 	{
 		if (&((*i)->bitmap)==bitmap)
 			(*i)->used=false;
